@@ -13,7 +13,7 @@ import pandas as pd
 from .structures import AddrMap, Pca
 from .structures import P, C, A
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 pwd_path = os.path.abspath(os.path.dirname(__file__))
 # 区划地址文件
@@ -32,6 +32,9 @@ def convert_to_unicode(text):
             text = text.decode('utf-8')
         except UnicodeDecodeError:
             text = text.decode('gbk', 'ignore')
+        except Exception as e:
+            import warnings
+            warnings.warn('Convert to unicode error: %s, text: %s' % (e, text))
     return text
 
 
